@@ -5,9 +5,6 @@
 #define __ENUM_GTYPES_H__
 #include <glib-object.h>
 G_BEGIN_DECLS
-/* enumerations from "parole-pl-parser.h" */
-GType parole_pl_format_get_type (void);
-#define ENUM_GTYPE_PL_FORMAT (parole_pl_format_get_type())
 /* enumerations from "parole-button.h" */
 GType parole_button_key_get_type (void);
 #define ENUM_GTYPE_BUTTON_KEY (parole_button_key_get_type())
